@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2015-2016 Montel Laurent <montel@kde.org>
+  Copyright (c) 2015-2019 Montel Laurent <montel@kde.org>
 
   This library is free software; you can redistribute it and/or modify it
   under the terms of the GNU Library General Public License as published by
@@ -41,7 +41,7 @@ public:
     void setEmailBlackList(const QStringList &lst);
     void setLdapClientSearch(KLDAP::LdapClientSearch *ldapSearch);
     void setRecentAddresses(const QStringList &lst);
-    bool recentAddressWasChanged() const;
+    Q_REQUIRED_RESULT bool recentAddressWasChanged() const;
     void storeAddresses(KConfig *config);
 
 private:
