@@ -107,7 +107,9 @@ public:
                                               Akonadi::CollectionFetchJob::Recursive);
 
         addressBookJob->fetchScope().setContentMimeTypes(mimeTypes);
-        q->connect(addressBookJob, SIGNAL(result(KJob *)), SLOT(slotCollectionsFetched(KJob *)));
+        q->connect(addressBookJob, &Akonadi::CollectionFetchJob::result, q, [this](KJob *job) {
+            slotCollectionsFetched(job);
+        });
     }
 
     void slotCollectionsFetched(KJob *job)
@@ -140,29 +142,34 @@ public:
                     i18nc("@info",
                           "You must create an address book before adding a contact. Do you want to create an address book?"),
                     i18nc("@title:window", "No Address Book Available")) == KMessageBox::Yes) {
-                Akonadi::AgentTypeDialog dlg(mParentWidget);
-                dlg.setWindowTitle(i18n("Add Address Book"));
-                dlg.agentFilterProxyModel()->addMimeTypeFilter(KContacts::Addressee::mimeType());
-                dlg.agentFilterProxyModel()->addMimeTypeFilter(KContacts::ContactGroup::mimeType());
-                dlg.agentFilterProxyModel()->addCapabilityFilter(QStringLiteral("Resource"));
+                QPointer<Akonadi::AgentTypeDialog> dlg = new Akonadi::AgentTypeDialog(mParentWidget);
+                dlg->setWindowTitle(i18n("Add Address Book"));
+                dlg->agentFilterProxyModel()->addMimeTypeFilter(KContacts::Addressee::mimeType());
+                dlg->agentFilterProxyModel()->addMimeTypeFilter(KContacts::ContactGroup::mimeType());
+                dlg->agentFilterProxyModel()->addCapabilityFilter(QStringLiteral("Resource"));
 
-                if (dlg.exec()) {
-                    const Akonadi::AgentType agentType = dlg.agentType();
+                if (dlg->exec()) {
+                    const Akonadi::AgentType agentType = dlg->agentType();
 
                     if (agentType.isValid()) {
                         Akonadi::AgentInstanceCreateJob *job = new Akonadi::AgentInstanceCreateJob(agentType, q);
-                        q->connect(job, SIGNAL(result(KJob *)), SLOT(slotResourceCreationDone(KJob *)));
+                        q->connect(job, &Akonadi::AgentInstanceCreateJob::result, q, [this](KJob *job) {
+                            slotResourceCreationDone(job);
+                        });
                         job->configure(mParentWidget);
                         job->start();
+                        delete dlg;
                         return;
                     } else { //if agent is not valid => return error and finish job
                         q->setError(UserDefinedError);
                         q->emitResult();
+                        delete dlg;
                         return;
                     }
                 } else { //Canceled create agent => return error and finish job
                     q->setError(UserDefinedError);
                     q->emitResult();
+                    delete dlg;
                     return;
                 }
             } else {
@@ -206,7 +213,9 @@ public:
 
         // save the new item in akonadi storage
         Akonadi::ItemCreateJob *createJob = new Akonadi::ItemCreateJob(item, addressBook, q);
-        q->connect(createJob, SIGNAL(result(KJob *)), SLOT(slotAddContactDone(KJob *)));
+        q->connect(createJob, &Akonadi::ItemCreateJob::result, q, [this](KJob *job) {
+            slotAddContactDone(job);
+        });
     }
 
     void slotAddContactDone(KJob *job)
@@ -224,7 +233,7 @@ public:
         if (mInteractive) {
             const QString text
                 = xi18nc("@info",
-                         "<para>A contact for <email>%1</email> was successfully added "
+                         "<para>A contact for \"%1\" was successfully added "
                          "to your address book.</para>"
                          "<para>Do you want to edit this new contact now?</para>",
                          mCompleteAddress);
@@ -240,10 +249,14 @@ public:
                     = new Akonadi::ContactEditorDialog(Akonadi::ContactEditorDialog::EditMode,
                                                        mParentWidget);
                 dlg->setContact(mItem);
-                connect(dlg, SIGNAL(contactStored(Akonadi::Item)),
-                        q, SLOT(contactStored(Akonadi::Item)));
-                connect(dlg, SIGNAL(error(QString)),
-                        q, SLOT(slotContactEditorError(QString)));
+                connect(dlg.data(), &Akonadi::ContactEditorDialog::contactStored,
+                        q, [this](const Akonadi::Item &item) {
+                    contactStored(item);
+                });
+                connect(dlg.data(), &Akonadi::ContactEditorDialog::error,
+                        q, [this](const QString &str) {
+                    slotContactEditorError(str);
+                });
                 dlg->exec();
                 delete dlg;
             }
@@ -269,9 +282,9 @@ public:
     QString mCompleteAddress;
     QString mEmail;
     QString mName;
-    QWidget *mParentWidget;
+    QWidget *mParentWidget = nullptr;
     Akonadi::Item mItem;
-    bool mInteractive;
+    bool mInteractive = false;
 };
 
 AddEmailAddressJob::AddEmailAddressJob(const QString &email, QWidget *parentWidget, QObject *parent)
@@ -292,7 +305,9 @@ void AddEmailAddressJob::start()
     searchJob->setLimit(1);
     searchJob->setQuery(Akonadi::ContactSearchJob::Email, d->mEmail.toLower(),
                         Akonadi::ContactSearchJob::ExactMatch);
-    connect(searchJob, SIGNAL(result(KJob *)), SLOT(slotSearchDone(KJob *)));
+    connect(searchJob, &Akonadi::ContactSearchJob::result, this, [this](KJob *job) {
+        d->slotSearchDone(job);
+    });
 }
 
 Akonadi::Item AddEmailAddressJob::contact() const
